@@ -45,7 +45,7 @@ class Field(object):
         self.__read_only.append(model_class)
 
     def is_read_only_in(self, model_class):
-        return model_class in self.__read_only or self.always_read_only
+        return (model_class in self.__read_only) or self.always_read_only
 
     def to_raw(self, data):
         return data
@@ -57,7 +57,6 @@ class Field(object):
             return unicode(data)
 
     def validate(self, data, model_instance):
-        print data, self
         if data is None or data=="":
             if self.blank or self.null or self.is_read_only_in(model_instance.__class__):
                 return None
@@ -99,6 +98,13 @@ class DateField(Field):
     def to_raw(self, data):
         return data.strftime("%Y-%m-%d")
 
+    def to_text(self, data):
+        try:
+            return data.strftime("%d.%m.%Y %H:%M")
+        except AttributeError:
+            return super(DateField, self).to_text(data)
+
+
 class DateTimeField(DateField):
     pass
 
@@ -106,6 +112,10 @@ class CharField(Field):
     pass
 
 
+class URLField(CharField):
+    def to_text(self, data):
+        return u'<a href="%s">%s</a>' %(data, data)
+
 
 class BooleanField(Field):
     pass
@@ -231,8 +241,8 @@ class Model(object):
     read_only_fields = []
     """@cvar: List of fields to read-only"""
 
-    include_methods_results = {}
-    """@cvar: Dict of methods to fetch from server"""
+    auto_user_fields = []
+
 
     dump_order = 0
     """@cvar: Order to dump"""
@@ -275,10 +285,16 @@ class Model(object):
         for method in cls.exclude_methods:
             setattr(cls, method, getattr(Model, method))
 
-        for method in cls.include_methods_results:
-            setattr(cls, method, cls.include_methods_results[method])
+        for methodname in dir(cls):
+            try:
+                if getattr(cls, methodname).method_as_field:
+                    setattr(cls, methodname, getattr(cls, methodname).method_as_field)
+                    getattr(cls, methodname).always_read_only = True
+            except AttributeError:
+                pass
 
-        for field in cls.read_only_fields+cls.include_methods_results.keys():
+        for field in cls.auto_user_fields+\
+                     cls.read_only_fields:
             getattr(cls, field).set_read_only_in(cls)
 
         for fieldname, field in cls.get_rel_fields().items():
@@ -326,7 +342,9 @@ class Model(object):
         """Returns raw model instance representation"""
         d = {}
         for fieldname, field in self.__class__.get_fields().items():
-            if fieldname!="id" and not field.is_read_only_in(self.__class__) and getattr(self, fieldname) is not None:
+            if (fieldname!="id") and\
+               (fieldname in self.auto_user_fields or not field.is_read_only_in(self.__class__) )\
+                    and getattr(self, fieldname) is not None:
                 d[fieldname]=unicode(field.to_raw(getattr(self, fieldname))).encode('utf-8')
         from pprint import pprint
         pprint(d)
@@ -515,6 +533,8 @@ class Model(object):
         """
         Saves object
         """
+        for user_field_name in self.auto_user_fields:
+            setattr(self, user_field_name, self.__models_manager.get_current_user())
 
         self.__dumped = False
         self.notify()
@@ -543,11 +563,31 @@ class Model(object):
 
 
 class User(Model):
-    #Todo: implement django behavoir
     resource_name = "django/users/"
-    username = CharField() 
-    first_name = CharField()
-    
+
+    username = CharField(u"Имя пользователя", max_length=30, unique=True)
+    first_name = CharField(u"Имя", max_length=30, blank=True)
+    last_name = CharField(u"Фамилия", max_length=30, blank=True)
+    email = EmailField(u"E-mail", blank=True)
+    password = CharField(u"Пароль", max_length=128)
+    is_staff = BooleanField(u"Статус персонала (доступ к админке)", default=False)
+    is_active = BooleanField(u"Активный", default=True)
+    is_superuser = BooleanField(u"Статус администратора", default=False)
+    last_login = DateTimeField(u"Последний вход")
+    date_joined = DateTimeField(u"Дата регистрации")
+#    groups = models.ManyToManyField(Group, verbose_name=_('groups'), blank=True,
+#       help_text=_("In addition to the permissions manually assigned, this user will also get all permissions granted to each group he/she is in."))
+#    user_permissions = models.ManyToManyField(Permission, verbose_name=_('user permissions'), blank=True)
+    class Meta:
+        verbose_name = u"Пользователь"
+        verbose_name_plural = u"Пользователи"
+
+    def __unicode__(self):
+        if self.last_name:
+            return self.last_name
+        else:
+            return self.username
+
 if __name__=="__main__":
     
     
